===============================
East-oriented Python
===============================

East-oriented Python examples, based on James Ladd's "East-oriented" technique http://jamesladdcode.com/?p=12.

* Free software: BSD license
* Documentation: https://eastpy.readthedocs.org.

Features
--------

* MovieFinder application ported from James Ladd's (@jamesladd) Java version
